/*
 * Sixth 3D engine demos. Copyright ©2012-2019, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 */

package eu.svjatoslav.sixth.e3d.examples;

import eu.svjatoslav.sixth.e3d.geometry.Point2D;
import eu.svjatoslav.sixth.e3d.geometry.Point3D;
import eu.svjatoslav.sixth.e3d.geometry.Rectangle;
import eu.svjatoslav.sixth.e3d.gui.ViewFrame;
import eu.svjatoslav.sixth.e3d.gui.ViewPanel;
import eu.svjatoslav.sixth.e3d.gui.textEditorComponent.TextEditComponent;
import eu.svjatoslav.sixth.e3d.math.Transform;
import eu.svjatoslav.sixth.e3d.renderer.raster.Color;
import eu.svjatoslav.sixth.e3d.renderer.raster.ShapeCollection;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.basic.line.LineAppearance;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.composite.wireframe.Grid2D;

public class TextEditorDemo {

    private static Grid2D createGrid() {
        final Transform transform = new Transform(new Point3D(0, 100, 0), 0,
                Math.PI / 2);

        final Rectangle rectangle = new Rectangle(2000);
        final LineAppearance appearance = new LineAppearance(10, new Color(
                "00b3ad"));

        return new Grid2D(transform, rectangle, 10, 10, appearance);
    }

    public static void main(final String[] args) {

        final ViewFrame viewFrame = new ViewFrame();
        final ViewPanel viewPanel = viewFrame.getViewPanel();

        final ShapeCollection shapeCollection = viewFrame.getViewPanel()
                .getRootShapeCollection();

        shapeCollection.addShape(createGrid());

        final double m = 1.5;
        for (double z = -500 * m; z <= (500 * m); z += 250 * m)
            for (double x = -500 * m; x <= (500 * m); x += 250 * m) {

                final TextEditComponent textEditor = new TextEditComponent(
                        new Transform(new Point3D(x, 0, z)), viewPanel,
                        new Point2D(200, 120));

                shapeCollection.addShape(textEditor);
            }

        viewPanel.getAvatar().setLocation(new Point3D(500, -300, -800));
        viewPanel.getAvatar().setAngleXZ(0.6);
        viewPanel.getAvatar().setAngleYZ(-0.5);

    }
}
